@@ -14,20 +14,20 @@
 // You should have received a copy of the GNU General Public License
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
-use super::{GroupAffine, GroupProjective};
+use super::{Affine, Projective};
 
 use snarkvm_utilities::{
-    bytes::ToBytes,
     io::Cursor,
     rand::UniformRand,
     serialize::{CanonicalDeserialize, CanonicalSerialize},
-    to_bytes,
+    to_bytes_le,
+    ToBytes,
 };
 
 use crate::traits::{
     pairing_engine::{AffineCurve, ProjectiveCurve},
-    MontgomeryModelParameters,
-    TEModelParameters,
+    MontgomeryParameters,
+    TwistedEdwardsParameters,
 };
 use snarkvm_fields::{Field, One, PrimeField, Zero};
 
@@ -38,18 +38,18 @@ pub const ITERATIONS: usize = 10;
 
 pub fn montgomery_conversion_test<P>()
 where
-    P: TEModelParameters,
+    P: TwistedEdwardsParameters,
 {
     // A = 2 * (a + d) / (a - d)
     let a = P::BaseField::one().double() * (P::COEFF_A + P::COEFF_D) * (P::COEFF_A - P::COEFF_D).inverse().unwrap();
     // B = 4 / (a - d)
     let b = P::BaseField::one().double().double() * (P::COEFF_A - P::COEFF_D).inverse().unwrap();
 
-    assert_eq!(a, P::MontgomeryModelParameters::COEFF_A);
-    assert_eq!(b, P::MontgomeryModelParameters::COEFF_B);
+    assert_eq!(a, P::MontgomeryParameters::COEFF_A);
+    assert_eq!(b, P::MontgomeryParameters::COEFF_B);
 }
 
-pub fn edwards_test<P: TEModelParameters>()
+pub fn edwards_test<P: TwistedEdwardsParameters>()
 where
     P::BaseField: PrimeField,
 {
@@ -58,13 +58,13 @@ where
     edwards_from_x_and_y_coordinates::<P>();
 }
 
-pub fn edwards_curve_serialization_test<P: TEModelParameters>() {
-    let buf_size = GroupAffine::<P>::zero().serialized_size();
+pub fn edwards_curve_serialization_test<P: TwistedEdwardsParameters>() {
+    let buf_size = Affine::<P>::zero().serialized_size();
 
     let mut rng = XorShiftRng::seed_from_u64(1231275789u64);
 
     for _ in 0..10 {
-        let a = GroupProjective::<P>::rand(&mut rng);
+        let a = Projective::<P>::rand(&mut rng);
         let a = a.into_affine();
         {
             let mut serialized = vec![0; buf_size];
@@ -72,22 +72,22 @@ pub fn edwards_curve_serialization_test<P: TEModelParameters>() {
             a.serialize(&mut cursor).unwrap();
 
             let mut cursor = Cursor::new(&serialized[..]);
-            let b = GroupAffine::<P>::deserialize(&mut cursor).unwrap();
+            let b = Affine::<P>::deserialize(&mut cursor).unwrap();
             assert_eq!(a, b);
         }
 
         {
-            let a = GroupAffine::<P>::zero();
+            let a = Affine::<P>::zero();
             let mut serialized = vec![0; buf_size];
             let mut cursor = Cursor::new(&mut serialized[..]);
             a.serialize(&mut cursor).unwrap();
             let mut cursor = Cursor::new(&serialized[..]);
-            let b = GroupAffine::<P>::deserialize(&mut cursor).unwrap();
+            let b = Affine::<P>::deserialize(&mut cursor).unwrap();
             assert_eq!(a, b);
         }
 
         {
-            let a = GroupAffine::<P>::zero();
+            let a = Affine::<P>::zero();
             let mut serialized = vec![0; buf_size - 1];
             let mut cursor = Cursor::new(&mut serialized[..]);
             a.serialize(&mut cursor).unwrap_err();
@@ -96,7 +96,7 @@ pub fn edwards_curve_serialization_test<P: TEModelParameters>() {
         {
             let serialized = vec![0; buf_size - 1];
             let mut cursor = Cursor::new(&serialized[..]);
-            GroupAffine::<P>::deserialize(&mut cursor).unwrap_err();
+            Affine::<P>::deserialize(&mut cursor).unwrap_err();
         }
 
         {
@@ -105,32 +105,32 @@ pub fn edwards_curve_serialization_test<P: TEModelParameters>() {
             a.serialize_uncompressed(&mut cursor).unwrap();
 
             let mut cursor = Cursor::new(&serialized[..]);
-            let b = GroupAffine::<P>::deserialize_uncompressed(&mut cursor).unwrap();
+            let b = Affine::<P>::deserialize_uncompressed(&mut cursor).unwrap();
             assert_eq!(a, b);
         }
 
         {
-            let a = GroupAffine::<P>::zero();
+            let a = Affine::<P>::zero();
             let mut serialized = vec![0; a.uncompressed_size()];
             let mut cursor = Cursor::new(&mut serialized[..]);
             a.serialize_uncompressed(&mut cursor).unwrap();
             let mut cursor = Cursor::new(&serialized[..]);
-            let b = GroupAffine::<P>::deserialize_uncompressed(&mut cursor).unwrap();
+            let b = Affine::<P>::deserialize_uncompressed(&mut cursor).unwrap();
             assert_eq!(a, b);
         }
     }
 }
 
-pub fn edwards_from_random_bytes<P: TEModelParameters>()
+pub fn edwards_from_random_bytes<P: TwistedEdwardsParameters>()
 where
     P::BaseField: PrimeField,
 {
-    let buf_size = GroupAffine::<P>::zero().serialized_size();
+    let buf_size = Affine::<P>::zero().serialized_size();
 
     let mut rng = XorShiftRng::seed_from_u64(1231275789u64);
 
     for _ in 0..ITERATIONS {
-        let a = GroupProjective::<P>::rand(&mut rng);
+        let a = Projective::<P>::rand(&mut rng);
         let a = a.into_affine();
         {
             let mut serialized = vec![0; buf_size];
@@ -138,46 +138,46 @@ where
             a.serialize(&mut cursor).unwrap();
 
             let mut cursor = Cursor::new(&serialized[..]);
-            let p1 = GroupAffine::<P>::deserialize(&mut cursor).unwrap();
-            let p2 = GroupAffine::<P>::from_random_bytes(&serialized).unwrap();
+            let p1 = Affine::<P>::deserialize(&mut cursor).unwrap();
+            let p2 = Affine::<P>::from_random_bytes(&serialized).unwrap();
             assert_eq!(p1, p2);
         }
     }
 
     for _ in 0..ITERATIONS {
-        let biginteger = <<GroupAffine<P> as AffineCurve>::BaseField as PrimeField>::BigInteger::rand(&mut rng);
-        let mut bytes = to_bytes![biginteger].unwrap();
-        let mut g = GroupAffine::<P>::from_random_bytes(&bytes);
+        let biginteger = <<Affine<P> as AffineCurve>::BaseField as PrimeField>::BigInteger::rand(&mut rng);
+        let mut bytes = to_bytes_le![biginteger].unwrap();
+        let mut g = Affine::<P>::from_random_bytes(&bytes);
         while g.is_none() {
             bytes.iter_mut().for_each(|i| *i = i.wrapping_sub(1));
-            g = GroupAffine::<P>::from_random_bytes(&bytes);
+            g = Affine::<P>::from_random_bytes(&bytes);
         }
         let _g = g.unwrap();
     }
 }
 
-pub fn edwards_from_x_and_y_coordinates<P: TEModelParameters>()
+pub fn edwards_from_x_and_y_coordinates<P: TwistedEdwardsParameters>()
 where
     P::BaseField: PrimeField,
 {
     let mut rng = XorShiftRng::seed_from_u64(1231275789u64);
 
     for _ in 0..ITERATIONS {
-        let a = GroupProjective::<P>::rand(&mut rng);
+        let a = Projective::<P>::rand(&mut rng);
         let a = a.into_affine();
         {
             let x = a.x;
 
-            let a1 = GroupAffine::<P>::from_x_coordinate(x, true).unwrap();
-            let a2 = GroupAffine::<P>::from_x_coordinate(x, false).unwrap();
+            let a1 = Affine::<P>::from_x_coordinate(x, true).unwrap();
+            let a2 = Affine::<P>::from_x_coordinate(x, false).unwrap();
 
             assert!(a == a1 || a == a2);
         }
         {
             let y = a.y;
 
-            let a1 = GroupAffine::<P>::from_y_coordinate(y, true).unwrap();
-            let a2 = GroupAffine::<P>::from_y_coordinate(y, false).unwrap();
+            let a1 = Affine::<P>::from_y_coordinate(y, true).unwrap();
+            let a2 = Affine::<P>::from_y_coordinate(y, false).unwrap();
 
             assert!(a == a1 || a == a2);
         }
